@@ -9,7 +9,7 @@
 # General and full license information is available at:
 #    https://github.com/plerup/makeEspArduino
 #
-# Copyright (c) 2016-2020 Peter Lerup. All rights reserved.
+# Copyright (c) 2016-2021 Peter Lerup. All rights reserved.
 #
 #====================================================================================
 
@@ -23,5 +23,5 @@ while (<>) {
   $flash_tot += $1 if /$flash_sections/;
   $ram_tot += $1 if /$ram_sections/;
 }
-print "\nMemory usage\n";
+print "\nMemory summary\n";
 print sprintf("  %-6s %6d bytes\n" x 2 ."\n", "RAM:", $ram_tot, "Flash:", $flash_tot);
