@@ -51,7 +51,7 @@ $vars{'build.mmuflags'} = '$(MMU_FLAGS)';
 $vars{'build.vtable_flags'} = '$(VTABLE_FLAGS)';
 $vars{'build.source.path'} = '$(dir $(SKETCH))';
 
-# Parse the files and define the corresponsing variables
+# Parse the files and define the corresponding variables
 my $board_defined;
 foreach my $fn (@ARGV) {
   my $f;
@@ -90,7 +90,6 @@ def_var('build.flash_mode', 'FLASH_MODE');
 def_var('build.flash_freq', 'FLASH_SPEED');
 def_var('upload.resetmethod', 'UPLOAD_RESET');
 def_var('upload.speed', 'UPLOAD_SPEED');
-def_var('compiler.warning_flags', 'COMP_WARNINGS');
 $vars{'serial.port'} = '$(UPLOAD_PORT)';
 $vars{'tools.esptool.upload.pattern'} =~ s/\{(cmd|path)\}/\{tools.esptool.$1\}/g;
 $vars{'compiler.cpreprocessor.flags'} .= " \$(C_PRE_PROC_FLAGS)";
@@ -105,6 +104,7 @@ foreach my $key (sort keys %vars) {
    $vars{$key} =~ s/ -o\s+$//;
    $vars{$key} =~ s/(-D\w+=)"([^"]+)"/$1\\"$2\\"/g;
 }
+def_var('compiler.warning_flags', 'COMP_WARNINGS');
 
 # Print the makefile content
 my $val;
@@ -117,7 +117,7 @@ print "# Commands\n";
 print "C_COM=\$(C_COM_PREFIX) $vars{'recipe.c.o.pattern'}\n";
 print "CPP_COM=\$(CPP_COM_PREFIX) $vars{'recipe.cpp.o.pattern'}\n";
 print "S_COM=$vars{'recipe.S.o.pattern'}\n";
-print "LIB_COM=\"$vars{'compiler.path'}$vars{'compiler.ar.cmd'}\"\n";
+print "LIB_COM=\"$vars{'compiler.path'}$vars{'compiler.ar.cmd'}\" $vars{'compiler.ar.flags'}\n";
 print "CORE_LIB_COM=$vars{'recipe.ar.pattern'}\n";
 print "LD_COM=$vars{'recipe.c.combine.pattern'}\n";
 print "PART_FILE?=\$(ESP_ROOT)/tools/partitions/default.csv\n";
@@ -147,7 +147,7 @@ print "RESTORE_FS_COM?=\"\$(MK_FS_PATH)\" -b \$(SPIFFS_BLOCK_SIZE) -s \$(SPIFFS_
 
 my $fs_upload_com = $vars{'tools.esptool.upload.pattern'} . " $vars{'tools.esptool.upload.pattern_args'}";
 $fs_upload_com =~ s/(.+ -ca) .+/$1 \$(SPIFFS_START) -cf \$(FS_IMAGE)/;
-$fs_upload_com =~ s/(.+ --flash_size detect) .+/$1 \$(SPIFFS_START) \$(FS_IMAGE)/;
+$fs_upload_com =~ s/(.+ --flash_size \S+) .+/$1 \$(SPIFFS_START) \$(FS_IMAGE)/;
 print "FS_UPLOAD_COM?=$fs_upload_com\n";
 $val = multi_com('recipe\.hooks*\.prebuild.*\.pattern');
 $val =~ s/bash -c "(.+)"/$1/g;
